@@ -27,7 +27,7 @@ use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS @ISA);
 #use LWP::Protocol::https;
 use Data::Dumper;
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 @ISA = qw(Exporter);
 @EXPORT = qw();
 @EXPORT_OK = qw(
@@ -138,15 +138,21 @@ sub add_google {
     my @jtitles=$tree->findvalues('//tr[@class="gsc_a_tr"]/td/div[@class="gs_gray"][2]');
     my $len1 = @atitles; my $len2 = @authors; my $len3 = @jtitles;
     if (($len1 != $len2) || ($len1 != $len3) || ($len2 != $len3)) {$self->_err("Problem parsing google page: mismatched $len1 titles/$len2 authors/$len3 journals.");return []}
-    my @cites=();
     for (my $i = 0; $i<$len1; $i++) {
       # these are already utf8
       $authors[$i] = decode_entities($authors[$i]);
       $atitles[$i] = decode_entities($atitles[$i]);
       $jtitles[$i] = decode_entities($jtitles[$i]);
-      $cites[$i] = $authors[$i].", ".$atitles[$i].", ".$jtitles[$i];
+      my $temp = $authors[$i].", ".$atitles[$i].", ".$jtitles[$i];
+      my $r = Bib::CrossRef->new;
+      $r->parse_text($temp);
+      $jtitles[$i] =~ m/\s([0-9][0-9][0-9][0-9])$/;
+      my $year=$1;
+      if ((length($year)==4) && ($r->date ne $1)) {
+        $r->_setscore(0.5); # mismatch in year, probably bad
+      }
+      $self->append($r);
     }
-    $self->add_details(@cites);
   } else {
     $self->_err("Problem with $url: ".$res->status_line);
   }
@@ -936,7 +942,7 @@ A simple web interface to Bib::Tools is contained in the examples folder.  This
 
 =head1 VERSION
  
-Ver 0.11
+Ver 0.12
  
 =head1 AUTHOR
  
